==> dcc-insider-plugin_0.1.11.tar.xz: BUILD/dcc-insider/translations/insider_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>dde::insider::InsiderWorker</name>
    <message>
        <source>Display manager switch successful</source>
        <translation>显示管理器切换成功</translation>
    </message>
    <message>
        <source>Display manager switch successful, changes will take effect after a restart.</source>
        <translation>显示管理器切换成功，重启后生效。</translation>
    </message>
    <message>
        <source>Restart Now</source>
        <translation>立即重启</translation>
    </message>
    <message>
        <source>Restart Later</source>
        <translation>稍后重启</translation>
    </message>
</context>
<context>
    <name>insider</name>
    <message>
        <source>Technology Preview</source>
        <translation>技术预览</translation>
    </message>
</context>
<context>
    <name>insiderMain</name>
    <message>
        <source>New Display Manager</source>
        <translation>新版显示管理器</translation>
    </message>
    <message>
        <source>New Input Method</source>
        <translation>新版输入法</translation>
    </message>
    <message>
        <source>Currently stable Input Method</source>
        <translation>当前稳定版输入法</translation>
    </message>
    <message>
        <source>Technology preview Input Method (deepin-im)</source>
        <translation>技术预览版输入法（deepin-im）</translation>
    </message>
    <message>
        <source>Currently stable Display Manager (LightDM)</source>
        <translation>当前稳定版显示管理器（LightDM）</translation>
    </message>
    <message>
        <source>Technology preview Display Manager/Window Manager (DDM/Treeland)</source>
        <translation>技术预览版显示管理器/窗口管理器(DDM/Treeland)</translation>
    </message>
    <message>
        <source>When experiencing the Treeland environment in a virtual machine, ensure 3D acceleration is enabled. Please note that the current Treeland environment does not support running Wine applications.</source>
        <translation>在虚拟机中体验 Treeland 环境时，请确保开启 3D 加速。同时需注意，当前 Treeland 环境暂不支持运行 Wine 应用程序。</translation>
    </message>
</context>
</TS>

==> dcc-insider-plugin_0.1.15.tar.xz: BUILD/dcc-insider/translations/insider_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>dde::insider::InsiderWorker</name>
    <message>
        <source>Display manager switch successful</source>
        <translation>显示管理器切换成功</translation>
    </message>
    <message>
        <source>Display manager switch successful, changes will take effect after a restart.</source>
        <translation>显示管理器切换成功，重启后生效。</translation>
    </message>
    <message>
        <source>Restart Now</source>
        <translation>立即重启</translation>
    </message>
    <message>
        <source>Restart Later</source>
        <translation>稍后重启</translation>
    </message>
</context>
<context>
    <name>insider</name>
    <message>
        <source>Technology Preview</source>
        <translation>技术预览</translation>
    </message>
</context>
<context>
    <name>insiderMain</name>
    <message>
        <source>New Display Manager</source>
        <translation>新版显示管理器</translation>
    </message>
    <message>
        <source>New Input Method</source>
        <translation>新版输入法</translation>
    </message>
    <message>
        <source>Currently stable Input Method</source>
        <translation>当前稳定版输入法</translation>
    </message>
    <message>
        <source>Technology preview Input Method (deepin-im)</source>
        <translation>技术预览版输入法（deepin-im）</translation>
    </message>
    <message>
        <source>Currently stable Display Manager (LightDM)</source>
        <translation>当前稳定版显示管理器（LightDM）</translation>
    </message>
    <message>
        <source>Technology preview Display Manager/Window Manager (DDM/Treeland)</source>
        <translation>技术预览版显示管理器/窗口管理器(DDM/Treeland)</translation>
    </message>
    <message>
        <source>When experiencing the Treeland environment in a virtual machine, ensure 3D acceleration is enabled. Please note that the current Treeland environment does not support running Wine applications.</source>
        <translation>在虚拟机中体验 Treeland 环境时，请确保开启 3D 加速。同时需注意，当前 Treeland 环境暂不支持运行 Wine 应用程序。</translation>
    </message>
</context>
</TS>
